@@ -19,7 +19,7 @@ article_index_local <- function(package, path = find.package(package)) {
     return(character())
   }
 
-  vig_path <- dir_ls(src, regexp = "\\.[rR]md$", recursive = TRUE, type = "file")
+  vig_path <- dir_ls(src, regexp = "\\.[rR]md$", recurse = TRUE, type = "file")
 
   out_path <- gsub("\\.[rR]md$", ".html", path_rel(vig_path, start = path_real(src)))
   vig_name <- gsub("\\.[rR]md$", "", path_file(vig_path))
