@@ -43,3 +43,18 @@ test_that("can link to implicit base topics", {
     "<span class='fu'><a href='https://rdrr.io/r/stats/median.html'>median</a></span>()"
   )
 })
+
+test_that("can parse code with carriage returns", {
+  scoped_package_context("test")
+
+  expect_equal(
+    highlight_text("1\r\n2"),
+    "<span class='fl'>1</span>\n<span class='fl'>2</span>"
+  )
+})
+
+test_that("unparsed code is still escaped", {
+  scoped_package_context("test")
+
+  expect_equal(highlight_text("<"), "&lt;")
+})
